@@ -1,14 +1,13 @@
 from abc import abstractmethod
 from typing import Any, Dict, List, Optional
 
-from pydantic import Field
-from pydantic.main import BaseModel
+from pydantic import Field, BaseSettings
 
 from obsei.payload import TextPayload
 from obsei.workflow.base_store import BaseStore
 
 
-class Convertor(BaseModel):
+class Convertor(BaseSettings):
     def convert(
         self,
         analyzer_response: TextPayload,
@@ -26,7 +25,7 @@ class Convertor(BaseModel):
         arbitrary_types_allowed = True
 
 
-class BaseSinkConfig(BaseModel):
+class BaseSinkConfig(BaseSettings):
     TYPE: str = "Base"
 
     @classmethod
@@ -37,16 +36,13 @@ class BaseSinkConfig(BaseModel):
         arbitrary_types_allowed = True
 
 
-class BaseSink(BaseModel):
+class BaseSink(BaseSettings):
     convertor: Convertor = Field(Convertor())
     store: Optional[BaseStore] = None
 
     @abstractmethod
     def send_data(
-        self,
-        analyzer_responses: List[TextPayload],
-        config: BaseSinkConfig,
-        **kwargs
+        self, analyzer_responses: List[TextPayload], config: BaseSinkConfig, **kwargs
     ):
         pass
 
