@@ -2,18 +2,16 @@ import logging
 from logging import Logger
 from typing import Any, List, Optional
 
-from obsei.analyzer.base_analyzer import AnalyzerResponse
+from pydantic import Field
+
+from obsei.payload import TextPayload
 from obsei.sink.base_sink import BaseSink, BaseSinkConfig, Convertor
 
 
 class LoggerSinkConfig(BaseSinkConfig):
     TYPE: str = "Logging"
-    logger: Optional[Logger] = None
-    level: Optional[int] = logging.INFO
-
-    def __init__(self, **data: Any):
-        super().__init__(**data)
-        self.logger = self.logger or logging.getLogger(__name__)
+    logger: Logger = Field(logging.getLogger(__name__))
+    level: int = Field(logging.INFO)
 
 
 class LoggerSink(BaseSink):
@@ -22,9 +20,9 @@ class LoggerSink(BaseSink):
     def __init__(self, convertor: Convertor = Convertor(), **data: Any):
         super().__init__(convertor=convertor, **data)
 
-    def send_data(
+    def send_data(  # type: ignore[override]
         self,
-        analyzer_responses: List[AnalyzerResponse],
+        analyzer_responses: List[TextPayload],
         config: LoggerSinkConfig,
         **kwargs,
     ):
@@ -36,6 +34,6 @@ class LoggerSink(BaseSink):
 
         for response in converted_responses:
             dict_to_print = (
-                response.__dict__ if hasattr(response, "__dict__") else response
+                vars(response) if hasattr(response, "__dict__") else response
             )
             config.logger.log(level=config.level, msg=f"{dict_to_print}")
