@@ -39,17 +39,18 @@ class FacebookSourceConfig(BaseSourceConfig):
 
         self.cred_info = self.cred_info or FacebookCredentials()
 
-        if (
-            self.cred_info.app_id is None
-            or self.cred_info.app_secret is None
-            or self.cred_info.long_term_token is None
-        ):
+        if self.cred_info.long_term_token is not None:
+            application_only_auth = False
+        elif self.cred_info.app_id is not None and self.cred_info.app_secret is not None:
+            application_only_auth = True
+        else:
             raise AttributeError("`app_id`, `app_secret` and `long_term_token` required to connect to Facebook")
 
         self._api_client = FacebookApi(
-            app_id=self.cred_info.app_id.get_secret_value(),
-            app_secret=self.cred_info.app_secret.get_secret_value(),
-            long_term_token=self.cred_info.long_term_token.get_secret_value(),
+            app_id=self.cred_info.app_id.get_secret_value() if self.cred_info.app_id else None,
+            app_secret=self.cred_info.app_secret.get_secret_value() if self.cred_info.app_secret else None,
+            access_token=self.cred_info.long_term_token.get_secret_value() if self.cred_info.long_term_token else None,
+            application_only_auth=application_only_auth,
         )
 
     def get_client(self) -> FacebookApi:
